import Qt 4.7

Rectangle {

    // Updated by the child rectangles whenever a mouse is
    // pressed on one of them.
    property string selectedColor: ""
    signal colorSelected

    id: rootRect
    anchors.margins: 5
    property bool flipped: false

    Flipable {
        id: flipColors
        width: childrenRect.width
        height: childrenRect.height

        // Each colorRect has additional colorString property
        // since the actual color property is in "#abcdef" format.
        // This rectangle is passed as parameter to each ColorRect
        // so they can update the selectedColor property. Not
        // really a good solution since there's a backward dependency.
        // A better one could use signal with colorString as parameter
        // to notify the change.
        front: Column {
            id: colorsColumn
            spacing: 5
            ColorRect { colorString: "white"; rootRect: rootRect; border.width: 1 }
            ColorRect { colorString: "orange"; rootRect: rootRect }
            ColorRect { colorString: "brown"; rootRect: rootRect }
            ColorRect { colorString: "pink"; rootRect: rootRect }
            ColorRect { colorString: "seagreen"; rootRect: rootRect }
        }

        back: Column {
            id: colorsColumnBack
            spacing: 5
            ColorRect { colorString: "red"; rootRect: rootRect }
            ColorRect { colorString: "green"; rootRect: rootRect }
            ColorRect { colorString: "blue"; rootRect: rootRect }
            ColorRect { colorString: "yellow"; rootRect: rootRect }
            ColorRect { colorString: "cyan"; rootRect: rootRect }
        }

        transform: Rotation {
            id: rotation;
            origin.x: flipColors.width / 2;
            origin.y: flipColors.height / 2
            axis.x: 0; axis.y: 1; axis.z: 0
        }

        states: State {
            name: "flip"
            when: rootRect.flipped
            PropertyChanges {
                target: rotation; angle: 180
            }
        }

        transitions: Transition {
            NumberAnimation { property: "angle"; easing.type: Easing.InOutQuad; duration: 600 }
        }
    }

    Rectangle {
        border.width: 1
        width: 50; height: 50
        anchors.top: flipColors.bottom
        anchors.topMargin: 5
        radius: 5
        Text {
            anchors.fill: parent
            text: "More..."
            verticalAlignment: Text.AlignVCenter
            horizontalAlignment: Text.AlignHCenter
        }
        MouseArea {
            anchors.fill: parent
            onClicked: rootRect.flipped = !rootRect.flipped
        }
    }
}
