import Qt 4.7

Rectangle {

    // Parent item for detached state
    property Item detachedParent: undefined

    id: rootRect
    width: 50; height: 50
    border.width: 1
    color: Qt.rgba(Math.random(), Math.random(), Math.random(), 255)

    // In detached state the parent is changed and
    // rectangle is scaled to twice it's size
    states:  [
        State {
            name: "detached"

            // Note that the x and y positions must be "changed".
            // Otherwise the reverse state change would not animate
            // x and y position changes.
            ParentChange {
                target: rootRect
                parent: detachedParent
                x: rootRect.x
                y: rootRect.y
            }

            PropertyChanges { target: rootRect; scale: 2.0 }
            StateChangeScript {
                script: detachedParent.detachCount++;
            }
        },
        // The default state may also have a state change script
        State {
            name: ""
            StateChangeScript {
                script: detachedParent.detachCount--;
            }
        }

    ]

    transitions: [
        Transition {
            from: ""; to: "detached"
            NumberAnimation { property: "scale" }
        },
        Transition {
            from: "detached"; to: ""
            SequentialAnimation {
                // Parent changes before animation, so this must be
                // temporarily brought above other siblings. If not,
                // the rectangles that have been added after this
                // rectangle would be on top. (Try commenting this out)
                PropertyAction { target: rootRect; property: "z"; value: 1 }

                // Animation must be wrapped into ParentAnimation, so
                // x and y positions get property animated instead of jump.
                ParentAnimation {
                    NumberAnimation { properties: "scale,x,y" }
                }

                // z-value is restored after animation is ready
                PropertyAction { target: rootRect; property: "z"; value: 0 }
            }
        }

    ]

    // Clicking on element toggles between the two states
    // Rectangle can be dragged around in detached state,
    // otherwise the drag events will go to parent Flickable surface
    MouseArea {
        anchors.fill: parent
        drag.target: parent.state == "detached" ? parent : undefined
        onClicked: {
            if (parent.state == "") {
                parent.state = "detached"
            } else {
                parent.state = ""
            }
        }
    }
}
