import Qt 4.7

Rectangle {
    width: 400
    height: 300

    // Fetch some pictures from flickr public feed
    XmlListModel {
        id: imageModel
        source: "http://api.flickr.com/services/feeds/photos_public.gne?format=rss2"
        query: "/rss/channel/item"
        namespaceDeclarations: "declare namespace media=\"http://search.yahoo.com/mrss/\";"
        XmlRole {
            name: "url";
            query: "media:thumbnail/@url/string()"
        }
    }

    // PathView has model and delegate as other views. In addition it has the path
    PathView {
        anchors.fill: parent
        model: imageModel
        delegate: imageDelegate

        path: Path {
            // Path starts from a point
            startX: 200; startY: 55

            // Path attributes are assigned to the previous
            // point in the path. In this case the start point
            // is fully opaque, unscaled and on top
            PathAttribute { name: "pathScale"; value: 1 }
            PathAttribute { name: "pathZ"; value: 1 }
            PathAttribute { name: "pathOpacity"; value: 1 }

            // A quad-curve is drawn from the start point to
            // right side of the view. The attributes are also
            // changed a bit.
            PathQuad { x: 360; y: 150; controlX: 360; controlY: 55 }
            PathAttribute { name: "pathScale"; value: 0.6 }
            PathAttribute { name: "pathZ"; value: 0.5 }
            PathAttribute { name: "pathOpacity"; value: 0.4 }

            // Next curve is drawn to bottom of the view.
            // Attributes are changed a bit more.
            PathQuad { x: 200; y: 245; controlX: 360; controlY: 245 }
            PathAttribute { name: "pathScale"; value: 0.3 }
            PathAttribute { name: "pathZ"; value: 0 }
            PathAttribute { name: "pathOpacity"; value: 0.1 }

            // Next curve goes to left side of the view. The attributes
            // are changed to same values as were on the right side
            PathQuad { x: 55; y: 150; controlX: 55; controlY: 245 }
            PathAttribute { name: "pathScale"; value: 0.6 }
            PathAttribute { name: "pathZ"; value: 0.5 }
            PathAttribute { name: "pathOpacity"; value: 0.4 }

            // Last curve is drawn back to the starting point.
            // The path attributes come from the starting point values
            // so no need to repeat them here.
            PathQuad { x: 200; y: 55; controlX: 55; controlY: 55 }
        }
    }

    // Delegate draws the image. Note that the path attributes
    // are not directly usable, but instead are used via the
    // PathView attached property.
    Component {
        id: imageDelegate
        Image {
            source: url
            width: 100; height: 100
            scale: PathView.pathScale
            z: PathView.pathZ
            opacity: PathView.pathOpacity
            smooth: true
        }
    }

}
