import Qt 4.7

Rectangle {
    id: delegateRect
    height: 20
    width: parent.width
    color: "lightblue"
    border.width: 1

    // Text element to display the title role from model elements
    Text {
        id: titleText
        anchors.top: parent.top
        anchors.left: parent.left
        anchors.right: parent.right
        height: 20
        anchors.leftMargin: 5

        // The model roles are referenced by name
        // If name is ambiguous for some reason,
        // model.title would also work
        text: title
        verticalAlignment: Text.AlignVCenter
        horizontalAlignment: Text.AlignLeft
    }

    // Text element to display the description role from model elements
    // Note that opacity is 0 in default state, so description is not visible
    Text {
        id: descriptionText
        anchors.top: titleText.bottom
        anchors.left: parent.left
        anchors.right: parent.right
        anchors.leftMargin: 5
        height: 20
        text: description
        opacity: 0
    }

    // In opened state the rectangle height is doubled
    // and description text opacity is changed to 1 so
    // it becomes visible.
    states: State {
        name: "opened"
        PropertyChanges {
            target: delegateRect
            height: 40
        }
        PropertyChanges {
            target: descriptionText
            opacity: 1
        }
    }

    // State change affects the height of the rectangle and
    // opacity of the description property
    transitions: [
        Transition {
            NumberAnimation { properties: "height,opacity" }
        }
    ]

    // View delegates have various attached properties it
    // gets from the ListView, GridView or PathView
    // onAdd signal handler is called every time an item
    // is added to the list view. Here the signal triggers
    // a signal handler animation
    // See ListView documentation for more details about
    // attached properties
    ListView.onAdd: NumberAnimation {
        target: delegateRect
        property: "x"
        from: -delegateRect.width
        to: 0
        easing.type: Easing.OutQuad
    }

    MouseArea {
        id: mouseArea
        anchors.fill: parent
        onClicked: {
            if (parent.state == "") {
                parent.state = "opened";
            } else {
                parent.state = "";
            }
        }
    }
}
