import Qt 4.7

// Modified version of AnimationGrouping example
// This one uses states instead of wrapping property
// changes into the animations directly.
Rectangle {
    width: 200
    height: 200

    // State changes are driven by a timer in this example
    property int ticks: 0

    // Add four rectangles, each default at point (25, 25)
    RedRect { id: rect1; text: "1" }
    RedRect { id: rect2; text: "2" }
    RedRect { id: rect3; text: "3" }
    RedRect { id: rect4; text: "4" }

    // Instead of defining animations with target positions, the
    // positions are wrapped into PropertyChanges under states.
    // Whenever a state becomes active, it's PropertyChanges are applied
    states: [
        State {
            name: "state1"
            when: ticks % 3 === 1
            PropertyChanges { target: rect1; x: 25; y: 25 }
            PropertyChanges { target: rect2; x: 150; y: 25 }
            PropertyChanges { target: rect3; x: 25; y: 150 }
            PropertyChanges { target: rect4; x: 150; y: 150 }
        },
        State {
            name: "state2"
            when: ticks % 3 === 2
            PropertyChanges { target: rect1; x: 150; y: 25 }
            PropertyChanges { target: rect2; x: 150; y: 150 }
            PropertyChanges { target: rect3; x: 25; y: 25 }
            PropertyChanges { target: rect4; x: 25; y: 150 }
        }
    ]

    // In the ParallelAnimations example the color and position
    // animations were grouped under the RedRectAnimation object.
    // In this case, the position transitions are specified here
    // and the color transitions within the RedRect states
    transitions: [
        Transition {
            SequentialAnimation {
                NumberAnimation { properties: "x,y"; duration: 500 }
            }
        }
    ]

    // Repeating timer, which drives the state changes
    Timer {
        id: timer
        repeat: true
        running: true
        interval: 1500
        onTriggered: ticks++
    }
}
